crown.radius: Calculate Tree Crown Radius

Description Usage Arguments Details Value Author(s)

View source: R/crown.radius.R

Description

Distance from stem position to farthest crown polygon vertex

Usage

1
crown.radius(crowns, stems = NULL)

Arguments

crowns,

tree crown geometries

stems,

stem positions

Details

If no stems are provided, the polygon centroids are used as stem positions

Value

vector with radi

Author(s)

Marvin Ludwig


envima/Rsenal2 documentation built on Oct. 16, 2020, 7:14 p.m.