Description Usage Arguments Details Value Author(s)
Distance from stem position to farthest crown polygon vertex
1 | crown.radius(crowns, stems = NULL)
|
crowns, |
tree crown geometries |
stems, |
stem positions |
If no stems are provided, the polygon centroids are used as stem positions
vector with radi
Marvin Ludwig
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.